
========
Glossary
========

.. glossary::

    BER
        *Basic Encoding Rules*.  A set of Abstract Syntax Notation One (ASN.1)
        encoding rules that are used to create the binary representation of
        LDAP protocol messages "on the wire".

    DIT
    DITs
        *Directory Information Tree*.  A tree-like representation of entries
        an LDAP service presents to clients.

    LDIF 
        The LDAP Data Interchange Format.  A plain text data format that
        can represent directory content or an update request.

